@@ -27,6 +27,7 @@ from ..code_chunks import CodeChunk, Include
 from .. import err
 from .. import message
 from .. import util
+from ..codebraid_defaults import CodebraidDefaults
 from .base import Converter
 
 
@@ -369,7 +370,10 @@ class PandocCodeChunk(CodeChunk):
     @property
     def code_hash(self):
         hasher = hashlib.sha1()
-        hasher.update(self.code_str.encode('utf8'))
+        if self.placeholder_code_lines:
+            hasher.update(self.placeholder_code_str.encode('utf8'))
+        else:
+            hasher.update(self.code_str.encode('utf8'))
         return hasher.hexdigest()
 
 
@@ -702,15 +706,12 @@ class PandocCodeChunk(CodeChunk):
                             else:
                                 raw_fmt = fmt
                             if fmt_text_display == 'raw':
-                                if fmt == 'markdown':
-                                    output_list.append(self._as_markdown_included_text(self.layout_output(output, 'raw', lines), inline=self.inline))
-                                else:
-                                    output_list.append(self._as_markdown_code(self.layout_output(output, 'raw', lines), inline=self.inline, raw=raw_fmt))
+                                output_list.append(self._as_markdown_included_text(self.layout_output(output, 'raw', lines), inline=self.inline))
                             elif fmt_text_display == 'verbatim':
                                 if lines:
-                                    output_list.append(self._as_markdown_code(self.layout_output(output, 'verbatim', lines), inline=self.inline, classes=fmt))
+                                    output_list.append(self._as_markdown_code(self.layout_output(output, 'verbatim', lines), inline=self.inline, classes=[fmt]))
                             elif fmt_text_display == 'verbatim_or_empty':
-                                output_list.append(self._as_markdown_code(self.layout_output(output, 'verbatim', lines), inline=self.inline, classes=fmt))
+                                output_list.append(self._as_markdown_code(self.layout_output(output, 'verbatim', lines), inline=self.inline, classes=[fmt]))
                             else:
                                 raise ValueError
                             break
@@ -981,6 +982,7 @@ class PandocConverter(Converter):
                 else:
                     origin_string += '\n\n<!--codebraid.eof-->\n\n'
                 self.origins[origin_name] = origin_string
+        if not pandoc_file_scope and len(self.origins) > 1:
             self.concat_origin_string = ''.join(self.origins.values())
 
         self.from_format_pandoc_extensions = from_format_pandoc_extensions
@@ -996,6 +998,8 @@ class PandocConverter(Converter):
         self._para_plain_origin_name_node_line_number = []
         self._final_ast = None
 
+        self.codebraid_defaults.update_from_yaml_metadata(next(iter(self.origins.values())))
+
 
     from_formats = set(['markdown', 'commonmark_x'])
     multi_origin_formats = set(['markdown', 'commonmark_x'])
@@ -1339,6 +1343,11 @@ class PandocConverter(Converter):
                 'pandoc-api-version' in ast and isinstance(ast['pandoc-api-version'], list) and
                 all(isinstance(x, int) for x in ast['pandoc-api-version']) and 'blocks' in ast):
             raise PandocError('Unrecognized AST format (incompatible Pandoc version?)')
+        for k in ('codebraid', 'codebraid_'):
+            try:
+                del ast['meta'][k]
+            except KeyError:
+                pass
         self._asts[single_origin_name] = ast
 
 
